Lots of things.

- First: read the question below. Try to resolve the issue yourself.
- Second: read the outstanding bugreports at pyjamas bugreports. Is there anything that vaguely looks related? Read up on it. Does the discussion there have any resolution?
- Third: decide whether the issue is best reported to the bugtracker or to pyjamas-dev or to both. The point of the bugtracker is to be a formal record of issues that need to be fixed. People's heads don't hold large amounts of information all the time, and priorities have to be assigned to tasks. If you want the issue to be fixed for you, you need to make life easier not less easy for the developers to fix it.
- Fourth: if you decide to contact pyjamas-dev, before you do so, there are some important things that you need to be aware of.
- pyjamas is a part-time community-driven project, not a corporate-funded one. your absolute top priority in contacting the development list is therefore to make it easy for people to respond. the way to make it easy for people to respond is to do your homework: to provide absolute unambiguous and full information necessary to get people "up to speed".
- To that end: if you have a problem, provide a complete worked example that can be downloaded and run as-is, with no additional effort required other than a few simple commands to install it and run it.
- Provide full context.
- Provide full context.
- Provide full context.
- Provide the version of the compiler; the version of python; the operating system; provide a complete list of all commands that had been run in order to get you to the point where you are, now.
- If you are running an out-of-date version of the compiler, update the application to the latest svn version of the compiler before contacting the list. There are insufficient resources to cater for older compilers. You are welcome to spend your time back-porting fixes to the older releases.
- In short: think. "Will the people receiving this have to be mind-readers in order to answer my question?". "What work will they have to do, to get me the results that I want?"
- Give some sort of clear indication of a willingness to work with the people of the list to resolve the issue that you have. A "hello, I'm new here, thank you in advance for any help" is usually all it takes, making the difference between the reader deciding to provide a terse but informative reply or a more detailed (and probably more useful) one.
- When you get a response, do what you've been recommended to do! You got an answer, so why would you want to be disrespectful to the person who spent their personal time and money in composing a reply, by not following their advice? If you don't understand the reply, that's fine - say so: there's no harm in saying, "I don't understand".
- The other alternative is: if you're not going to do what you've been recommended to do, give really good reasons as to why. The point is: don't risk alienating the very people you need help from, in order to fix the problem. Entertain them with the antics that you're getting up to by getting into a horribly tangly mess: yes. Irritate them by wasting their time: no.
- Once you've managed to solve a problem (in part or in full), say so. And, if the solution involved following advice given, say thank you!. The former is important for anyone else who may encounter the same problem. The latter is important for if you want to ask their advice ever again. If you don't say "thank you", don't be surprised to get a curt response next time, if you get one at all.

[Personal note from lkcl: I've done a lot of free software development, and I've never, despite trying, been able to cover exactly everything, first time, on reporting a problem / asking for help. Software development is complex. "Full" reports are rare and time-consuming for the person writing them, but that's just part of your job of writing your app. The key thing is that there should be enthusiasm behind what you're doing: a good developer on a free software project will be able to instantly tell that you're being enthusiastic (and are showing a willingness to adapt), and will likely make allowances that they would otherwise not tolerate. The bottom line is, therefore: use your judgement; provide as much information and context as you can; give some sort of indication of willingness to follow the advice given; follow the advice given; provide people with evidence that you've followed it (or an explanation as to why you haven't), and say thank you if the advice helped.]